.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://readthedocs.org/projects/gantt-project-maker/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://gantt-project-maker.readthedocs.io/en/stable/

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

===================
gantt-project-maker
===================


    A tool to make Gantt Project charts


This tool is a front end to the Python module python-gantt in order to easily set up your projects


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
